﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.UltraChart.Core.Layers;
using System.Diagnostics;
using Infragistics.UltraChart.Core.Primitives;

namespace CompositeChart
{
    public partial class Form1 : Form
    {
        private DataTable dt;
        private ScatterChartAppearance sca1;
        private ScatterChartAppearance sca2;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {

            this.ultraChart1.ChartType = ChartType.Composite;

            ChartArea area = new ChartArea();
            this.ultraChart1.CompositeChart.ChartAreas.Add(area);

            dt = new DataTable();
            dt.Columns.Add("Month", typeof(string));
            dt.Columns.Add("MonthID", typeof(int));
            dt.Columns.Add("2010", typeof(double));
            dt.Columns.Add("2011", typeof(double));
            dt.Columns.Add("2012", typeof(double));

            dt.Rows.Add("Jan", -10, 10, -40, -30);
            dt.Rows.Add("Feb", 20, 20, 35, 40);
            dt.Rows.Add("Mar", -30, 30, -30, -45);
            dt.Rows.Add("Apr", 10, -15, -40, null);
            dt.Rows.Add("May", 30, 20, 35, null);
            dt.Rows.Add("Jun", -20, -20, 25, null);


            AxisItem axisX = new AxisItem();
            axisX.OrientationType = AxisNumber.X_Axis;
            axisX.Extent = 40;
            axisX.DataType = AxisDataType.Numeric;
            axisX.NumericAxisType = NumericAxisType.Linear;
            axisX.LineColor = Color.Black;
            axisX.Labels.Visible = true;
            axisX.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            axisX.Labels.ItemFormat = AxisItemLabelFormat.DataValue;
            axisX.Labels.Visible = true;
            axisX.Labels.ItemFormatString = "<DATA_VALUE:##>";
            axisX.MajorGridLines.Visible = true;
            axisX.MajorGridLines.DrawStyle = LineDrawStyle.Dash;

            axisX.RangeType = AxisRangeType.Custom;
            axisX.RangeMin = -50;
            axisX.RangeMax = 50;

            area.Axes.Add(axisX);

            AxisItem axisY = new AxisItem();
            axisY.Extent = 20;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:00.00>";
            axisY.Labels.Visible = true;
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.LineColor = Color.Black;
            axisY.MajorGridLines.Visible = true;
            axisY.MajorGridLines.DrawStyle = LineDrawStyle.Dash;
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = -50;
            axisY.RangeMax = 50;
            area.Axes.Add(axisY);


            XYSeries series1 = new XYSeries();
            series1.Label = "Year 2010";
            series1.DataBind(dt, "MonthID", "2010", "Month");
            series1.PEs.Add(new PaintElement(Color.Blue));

            XYSeries series2 = new XYSeries();
            series2.Label = "Year 2011";
            series2.DataBind(dt, "MonthID", "2011", "Month");
            series2.PEs.Add(new PaintElement(Color.Red));

            XYSeries series3 = new XYSeries();
            series3.Label = "Year 2012";
            series3.DataBind(dt, "MonthID", "2012", "Month");
            series3.PEs.Add(new PaintElement(Color.Yellow));


            ChartLayerAppearance myColumnLayer = new ChartLayerAppearance();
            myColumnLayer.ChartType = ChartType.ScatterChart;
            myColumnLayer.ChartArea = area;
            myColumnLayer.Series.Add(series1);
            myColumnLayer.AxisX = axisX;
            myColumnLayer.AxisY = axisY;
            ultraChart1.CompositeChart.Series.Add(series1);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer);


            ChartLayerAppearance myColumnLayer2 = new ChartLayerAppearance();
            myColumnLayer2.ChartType = ChartType.ScatterChart;
            myColumnLayer2.ChartArea = area;
            myColumnLayer2.AxisX = axisX;
            myColumnLayer2.AxisY = axisY;
            myColumnLayer2.Series.Add(series2);
            ultraChart1.CompositeChart.Series.Add(series2);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer2);

            ChartLayerAppearance myColumnLayer3 = new ChartLayerAppearance();
            myColumnLayer3.ChartType = ChartType.ScatterChart;
            myColumnLayer3.ChartArea = area;
            myColumnLayer3.AxisX = axisX;
            myColumnLayer3.AxisY = axisY;
            myColumnLayer3.Series.Add(series3);
            ultraChart1.CompositeChart.Series.Add(series3);
            this.ultraChart1.CompositeChart.ChartLayers.Add(myColumnLayer3);


            sca1 = new ScatterChartAppearance();
            sca1.ConnectWithLines = false;
            sca1.Icon = SymbolIcon.Circle;
            sca1.IconSize = SymbolIconSize.Large;
            myColumnLayer.ChartTypeAppearance = sca1;

            sca2 = new ScatterChartAppearance();
            sca2.ConnectWithLines = false;
            sca2.Icon = SymbolIcon.Triangle;
            sca2.IconSize = SymbolIconSize.Large;
            myColumnLayer2.ChartTypeAppearance = sca2;
            myColumnLayer3.ChartTypeAppearance = sca2;

            ultraComboEditor1.Items.Add(SymbolIcon.Circle);
            ultraComboEditor1.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor1.Items.Add(SymbolIcon.Plus);
            ultraComboEditor1.Items.Add(SymbolIcon.Square);
            ultraComboEditor1.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor1.Value = SymbolIcon.Circle;

            ultraComboEditor2.Items.Add(SymbolIcon.Circle);
            ultraComboEditor2.Items.Add(SymbolIcon.Diamond);
            ultraComboEditor2.Items.Add(SymbolIcon.Plus);
            ultraComboEditor2.Items.Add(SymbolIcon.Square);
            ultraComboEditor2.Items.Add(SymbolIcon.Triangle);
            ultraComboEditor2.Value = SymbolIcon.Triangle;

        }

        private void ultraButton3_Click(object sender, EventArgs e)
        {
            ultraChart1.SaveTo(@"..\\..\\Test.bmp", System.Drawing.Imaging.ImageFormat.Bmp);
            Process.Start("..\\..\\Test.bmp");
        }

        private void ultraComboEditor1_ValueChanged(object sender, EventArgs e)
        {
            sca1.Icon = (SymbolIcon)ultraComboEditor1.Value;
        }

        private void ultraComboEditor2_ValueChanged(object sender, EventArgs e)
        {
            sca2.Icon = (SymbolIcon)ultraComboEditor2.Value;
        }

        private void ultraChart1_FillSceneGraph(object sender, Infragistics.UltraChart.Shared.Events.FillSceneGraphEventArgs e)
        {

            foreach (Primitive item in e.SceneGraph)
            {

                if (item.GetType() == typeof(Line) && ((Line)item).lineStyle.DrawStyle != LineDrawStyle.Dash)
                {
                    if (((Line)item).p1.X == ((Line)item).p2.X)
                    {
                        ((Line)item).p1.Offset(this.ultraChart1.Width / 2 - 23, 0);
                        ((Line)item).p2.Offset(this.ultraChart1.Width / 2 - 23, 0);
                    }
                    else
                    {
                        ((Line)item).p1.Offset(0, -this.ultraChart1.Height / 3 - 42);
                        ((Line)item).p2.Offset(0, -this.ultraChart1.Height / 3 - 42);
                    }
                }

                Text pl = item as Text;
                if (pl != null && ((Text)item).labelStyle.Orientation == TextOrientation.VerticalLeftFacing)
                {
                    ((Text)item).bounds = new Rectangle(((Text)item).bounds.X, ((Text)item).bounds.Y - (this.ultraChart1.Height / 3 +42), ((Text)item).bounds.Width, ((Text)item).bounds.Height);
                }

                if (pl != null && ((Text)item).labelStyle.Orientation == TextOrientation.Horizontal)
                {
                    ((Text)item).bounds = new Rectangle(((Text)item).bounds.X + this.ultraChart1.Width / 2 - 23, ((Text)item).bounds.Y, ((Text)item).bounds.Width, ((Text)item).bounds.Height);
                }


            }
        }

    }
}